clear_flag

Function clear_flag 

pub fn clear_flag(wflg: i32, wbig: i32, w: &mut [i32]) -> i32
Reset the generation counter wflg without visiting iw.

Called when wflg would overflow the wbig ceiling, or when it drops below 2 (which should not happen in practice, but matches SuiteSparse AMD’s defensive check). All nonzero entries in w are clamped to 1, and 2 is returned as the fresh counter.

Reference: amd.rs:130-143.